Struct ReflexIndex
Source pub struct ReflexIndex { }
In-memory reflex index for recent/high-importance atoms.
Constant-time append (modulo lock acquisition).
Filter atoms in the reflex window using the provided criteria.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.